#include <bits/stdc++.h>
using namespace std;

map< tuple<int,int,int,int,int>, vector< vector<string> > > PRECOMPUTED;

void init() {
#include "e-precomputed.h"
}

// a helper function to transpose all solutions if needed
vector< vector<string> > fix(const vector< vector<string> > &what, bool swapRC) {
    if (!swapRC) return what;
    vector< vector<string> > output;
    for (const auto &matrix : what) {
        vector<string> transposed( matrix[0].size(), string( matrix.size(), ' ' ) );
        for (unsigned r=0; r<matrix.size(); ++r) for (unsigned c=0; c<matrix[0].size(); ++c) transposed[c][r] = matrix[r][c];
        output.push_back(transposed);
    }
    return output;
}

// a special case: inputs where R == 2 or C == 2
vector< vector<string> > solve_two(int R, int C, int M, int clickR, int clickC) {
    // if needed, transpose the input to get R == 2
    bool swapRC = false;
    if (R != 2) { swap(R,C); swap(clickR,clickC); swapRC = true; }

    // if C <= 5, return precomputed answers to avoid special cases
    if (C <= 5) return fix( PRECOMPUTED[ make_tuple(R,C,M,clickR,clickC) ], swapRC );

    // try all possibilities for the range [f0,l0] of columns that contain zeros
    for (int f0=0; f0<=clickC; ++f0) for (int l0=clickC; l0<=C-1; ++l0) {
        // the range cannot begin/end one cell from the end
        if (f0==1) continue;
        if (l0==C-2) continue;

        // construct the set of cells that will not be adjacent to revealed cells
        vector< pair<int,int> > free_cells;
        for (int i=0; i<=f0-3; ++i) { free_cells.push_back( {0,i} ); free_cells.push_back( {1,i} ); }
        for (int i=l0+3; i<C; ++i) { free_cells.push_back( {0,i} ); free_cells.push_back( {1,i} ); }
        
        // compute the bounds on how many mines we can fit with our zeros
        int fewest_mines = int(f0 >= 2) + int(l0 <= C-3) + int(free_cells.size() > 0);
        int most_mines = int(f0 >= 2) + int(l0 <= C-3) + (free_cells.empty() ? 0 : free_cells.size()-1);
        if (M < fewest_mines || M > most_mines) continue;
        int free_mines = M - int(f0 >= 2) - int(l0 <= C-3);

        // if we are within range, generate one set of possible outputs
        vector< vector<string> > OUTPUT;
        if (free_cells.empty()) {
            for (int r=0; r<2; ++r) {
                vector<string> tmp(2, string(C,'.'));
                if (f0 >= 2) tmp[r][f0-2] = '*';
                if (l0 <= C-3) tmp[r][l0+2] = '*';
                OUTPUT.push_back( tmp );
            }
        } else {
            for (int f=0; f<free_cells.size()+1; ++f) {
                vector<string> tmp(2, string(C,'.'));
                int r = f%2;
                if (f0 >= 2) tmp[r][f0-2] = '*';
                if (l0 <= C-3) tmp[r][l0+2] = '*';
                for (int i=0; i<free_mines; ++i) {
                    int j = (f+i) % free_cells.size();
                    tmp[ free_cells[j].first ][ free_cells[j].second ] = '*';
                }
                OUTPUT.push_back( tmp );
            }
        }
        return fix( OUTPUT, swapRC );
    }
    return {};
}

// the general case: given a small precomputed collection of templates == patterns of mines placed at distance 2 from the click, 
// generate a set of configurations that solves the task
vector< vector<string> > generate_all(int R, int C, int M, int clickR, int clickC, const vector< vector<string> > &templates, int tdr, int tdc) {
    vector< vector<string> > OUTPUT;
    
    // construct the set of cells that are not adjacent to revealed cells
    vector< pair<int,int> > distance_3plus_from_click;
    for (int r=0; r<R; ++r) for (int c=0; c<C; ++c) if (max( abs(r-clickR) , abs(c-clickC) ) >= 3) distance_3plus_from_click.push_back( {r,c} );

    // generate options until you are sure you have enough
    int next_option = 0, next_other_cell = 0;
    
    while (true) {
        // create an empty map
        vector<string> current_map( R, string(C,'.') );

        // copy the current template onto the map, count the mines already placed
        int current_mines_placed = 0;
        for (int dr=-2; dr<=2; ++dr) for (int dc=-2; dc<=2; ++dc) {
            int tr = tdr+dr, tc = tdc+dc, tid = next_option%templates.size();
            if (tr < 0 || tr >= templates[tid].size() || tc < 0 || tc >= templates[tid][0].size()) continue;
            if (templates[tid][tr][tc] == '*') { ++current_mines_placed; current_map[clickR+dr][clickC+dc] = '*'; }
        }
        ++next_option;

        // a necessary optimization for some borderline cases:
        // if we already used each template at least once, skip those for which all mines/all nonmines are in the template
        if (next_option > int(templates.size()) && (current_mines_placed == M || M-current_mines_placed == int(distance_3plus_from_click.size()))) continue;

        // place the remaining mines onto the next cyclic segment of cells in distance_3plus_from_click
        for (int i=0; i < M - current_mines_placed; ++i) {
            int r, c;
            tie(r,c) = distance_3plus_from_click[ next_other_cell % distance_3plus_from_click.size() ];
            ++next_other_cell;
            current_map[r][c] = '*';
        }

        // append the current map to the output
        OUTPUT.push_back(current_map);

        // check the terminating conditions:
        // - each template has been used at least once
        // - each distance_3plus_from_click cell has already been covered by a mine at least once
        // - the total number of mines placed onto distance_3plus_from_click is small enough
        //   to make us sure each of them was already empty at least once
        if (next_option >= int(templates.size()) 
                && next_other_cell >= distance_3plus_from_click.size() 
                && OUTPUT.size() > (next_other_cell + distance_3plus_from_click.size() - 1) / distance_3plus_from_click.size()) 
            break;
    }
    assert( OUTPUT.size() <= R*C );
    return OUTPUT;
}

// solve all situations when the click is at least 2 cells from each side
vector< vector<string> > solve_inside(int R, int C, int M, int clickR, int clickC) {
    if (M < 5 || M > R*C-14) return {};
    return generate_all( R, C, M, clickR, clickC, (M <= R*C-21 ? PRECOMPUTED[ make_tuple(5,6,5,2,2) ] : PRECOMPUTED[ make_tuple(5,6,16,2,2) ]), 2, 2 );
}

// solve all situations when the click is on a side, at least 2 from each corner
vector< vector<string> > solve_on_a_side(int R, int C, int M, int clickR, int clickC) {
    if (M < 4 || M > R*C-10) return {};
    vector< vector<string> > OUTPUT;
    vector< vector<string> > templates;
    int tdr=-1, tdc=-1;
    int mines = (M <= R*C-12 ? 4 : 15);
    if (clickR == 0)   { templates = PRECOMPUTED[ make_tuple(5,5,mines,0,2) ]; tdr = 0; tdc = 2; }
    if (clickR == R-1) { templates = PRECOMPUTED[ make_tuple(5,5,mines,4,2) ]; tdr = 4; tdc = 2; }
    if (clickC == 0)   { templates = PRECOMPUTED[ make_tuple(5,5,mines,2,0) ]; tdr = 2; tdc = 0; }
    if (clickC == C-1) { templates = PRECOMPUTED[ make_tuple(5,5,mines,2,4) ]; tdr = 2; tdc = 4; }
    return generate_all( R, C, M, clickR, clickC, templates, tdr, tdc );
}

int main() {
    init();

    int T;
    cin >> T;

    for (int test=0; test<T; ++test) {
        int R, C, M, clickR, clickC;
        cin >> R >> C >> M >> clickR >> clickC;
        fprintf(stderr,"Solving test %d: R %d C %d ; %d mines ; click at %d %d\n",test,R,C,M,clickR,clickC);

        if (R == 1 || C == 1) { cout << "IMPOSSIBLE\n"; continue; }

        vector< vector<string> > OUTPUT;

        if (R == 2 || C == 2) {
            OUTPUT = solve_two(R,C,M,clickR,clickC);
        } else {
            // corners are impossible
            if ((clickR == 0 || clickR == R-1) && (clickC == 0 || clickC == C-1)) { cout << "IMPOSSIBLE\n"; continue; }

            // one cell from a side is impossible
            if (clickR == 1 || clickR == R-2 || clickC == 1 || clickC == C-2) { cout << "IMPOSSIBLE\n"; continue; }

            // if we are small, use brute force, otherwise use precomputed templates
            if (R <= 5 && C <= 5) {
                OUTPUT = PRECOMPUTED[ make_tuple(R,C,M,clickR,clickC) ];
            } else {
                if (2 <= clickR && clickR+2 < R && 2 <= clickC && clickC+2 < C) {
                    OUTPUT = solve_inside(R,C,M,clickR,clickC);
                } else {
                    OUTPUT = solve_on_a_side(R,C,M,clickR,clickC);
                }
            }
        }
        
        if (OUTPUT.empty()) { cout << "IMPOSSIBLE\n"; continue; }

        //while (OUTPUT.size() < R*C) OUTPUT.push_back( OUTPUT.back() );
        cout << OUTPUT.size() << endl;
        for (const auto &option : OUTPUT) for (const auto &row : option) cout << row << endl;
    }
}
